ngff_zarr.detect_cli_io_backend - ngff-zarr
Description: Module Contents: Functions:,, detect_cli_io_backend,,,,, Data:,, conversion_backends,,, conversion_backends_values,,, ConversionBackend,,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Edit this page
Toggle table of contents sidebar

# `ngff_zarr.detect_cli_io_backend`

## Module Contents

### Functions

`detect_cli_io_backend` |

### Data

`conversion_backends` |
`conversion_backends_values` |
`ConversionBackend` |

### API

ngff_zarr.detect_cli_io_backend.conversion_backends

  [(‘NGFF_ZARR’, ‘ngff_zarr’), (‘ZARR_ARRAY’, ‘zarr’), (‘ITKWASM’, ‘itkwasm_image_io’), (‘ITK’, ‘itk’)…

ngff_zarr.detect_cli_io_backend.conversion_backends_values

  None

ngff_zarr.detect_cli_io_backend.ConversionBackend

  ‘Enum(…)’

ngff_zarr.detect_cli_io_backend.detect_cli_io_backend(input: List[str]) → ngff_zarr.detect_cli_io_backend.ConversionBackend